@@ -8,19 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_events._jsii
-import aws_cdk.aws_events_targets._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-temp-stack",
-    "1.50.0",
+    "2.0.0",
     __name__[0:-6],
-    "cdk-temp-stack@1.50.0.jsii.tgz",
+    "cdk-temp-stack@2.0.0.jsii.tgz",
 )
 
 __all__ = [
